@@ -75,7 +75,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 /*
  * Global variables 
  */
-static char * progver   = "2.97";
+static char * progver   = "3.00";
 static char * progname  = "ialarms";
 static char   fdebug    = 0;
 static char   fbmctam   = 0;
@@ -112,6 +112,7 @@ extern int get_led_status_intel(uchar *pstate);
 static uchar busid = PRIVATE_BUS_ID;
 static uchar enc_sa = HSC_SA;
 static char fRomley = 0;
+static char fGrantley = 0;
 
 static int get_enc_leds(uchar *val)
 {
@@ -488,12 +489,13 @@ main(int argc, char **argv)
 	ret = detect_capab_intel(vend_id,prod_id,&flags,&maxdisks,fdebug); 
 	busid = (uchar)ret;
 	if (fdebug) printf("prod_capab: busid=%x, flags=%02x\n",busid,flags);
-	if ((flags & HAS_ALARMS_MASK) != 0) fHasAlarms = 1;
-	if ((flags & HAS_BMCTAM_MASK) != 0) fbmctam = 1;
-	if ((flags & HAS_ENCL_MASK) != 0)   fHasEnc = 1;
-	if ((flags & HAS_PICMG_MASK) != 0)  fpicmg = 1;
-	if ((flags & HAS_NSC_MASK) != 0)    fNSC = 1;
-	if ((flags & HAS_ROMLEY_MASK) != 0) fRomley = 1;
+	if ((flags & HAS_ALARMS_MASK) != 0)   fHasAlarms = 1;
+	if ((flags & HAS_BMCTAM_MASK) != 0)   fbmctam = 1;
+	if ((flags & HAS_ENCL_MASK) != 0)     fHasEnc = 1;
+	if ((flags & HAS_PICMG_MASK) != 0)    fpicmg = 1;
+	if ((flags & HAS_NSC_MASK) != 0)      fNSC = 1;
+	if ((flags & HAS_ROMLEY_MASK) != 0)   fRomley = 1;
+	if ((flags & HAS_GRANTLEY_MASK) != 0) fGrantley = 1;
 	/* get ID LED status */
 	ret = get_led_status_intel(&idstate);
         if (ret == 0) {
@@ -613,11 +615,11 @@ main(int argc, char **argv)
    }
 
    if (fHasEnc && fdoencl) {  /* disk enclosure exists */
-     if (fRomley) {   /* Romley (Patsburg) */
+     if (fRomley || fGrantley) {   /* Romley (Patsburg) */
        int rv;  /*do not change ret*/
        rv = get_enc_leds_intel(&encled);
        if (rv == 0) {
-	 show_enc_leds_intel(encled,maxdisks);
+         show_enc_leds_intel(encled,maxdisks);
          if (fsetdisk) {
 	    /* Set fault if user param, and disk is present. */
             if (fsetall) newvalue = 0x00;   /* all LEDs off */
