@@ -76,7 +76,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define  SELprintf  printf  
 #define  SMS_SA   0x41
 #define  SMI_SA   0x21
-static char *progver   = "2.97";
+static char *progver   = "3.00";
 static char *progname  = "ievents";
 static char fsensdesc = 0;   /* 1= get extended sensor descriptions*/
 static char fcanonical = 0;  /* 1= show canonical, delimited output*/
@@ -1601,7 +1601,31 @@ int decode_sel_entry( uchar *pevt, char *outbuf, int szbuf)
 	j = decode_sel_oem(vend,pevt,outbuf,szbuf,fsensdesc,fdebug);
 	if (j == 0) return(0);  /*successful, have the description*/
 
-	if (psel->record_type == 0xDC) {
+	if (psel->record_type == RT_OEMIU) { /* 0xDB usu ipmiutil OEM string */
+		   int ix = 0;
+		   /* ipmiutil OEM event with 9-byte string */
+		   pc = (uchar *)&psel->generator_id;  /* offset 7 */
+		   evtime = (uchar *)&psel->timestamp;
+		   eventTime = evtime[0] + (evtime[1] << 8) + 
+		   		(evtime[2] << 16) + (evtime[3] << 24);
+		   fmt_time(eventTime, timebuf, sizeof(timebuf));
+		   if (fcanonical) 
+		     sprintf(outbuf,"%04x %c %s %c %s %c %02x %c %06x %c %s %c OEM Event ",
+                       psel->record_id, bdelim, timebuf, bdelim, 
+                       get_sev_str(sev), bdelim, psel->record_type, bdelim);
+		   else
+		     sprintf(outbuf,"%04x %s %s %02x OEM Event ", 
+			   psel->record_id, timebuf, get_sev_str(sev),
+			   psel->record_type);
+		   j = strlen_(outbuf);
+		   for (i = 0; i < 9; i++) {  /* 7:16 = 9 bytes string data */
+			   if (pc[i] == 0) outbuf[j] = ' ';
+			   else sprintf(&outbuf[j],"%c",pc[i]);
+			   j += 1;
+		   }
+		   outbuf[j++] = '\n';
+		   outbuf[j++] = 0;
+	} else if (psel->record_type == 0xDC) {
 		   /* OEM Record: these are usually Microsoft */
 		   char *mfgstr;
 		   int mfg;
@@ -2221,7 +2245,7 @@ int decode_raw_sel(char *raw_file, int mode)
 {
       FILE *fp;
       char buff[256];
-      uchar msg[132];
+      char msg[132];
       uchar hbuf[50];
       int fvalid = 0;
       int len, i;
@@ -2585,7 +2609,7 @@ int i_events(int argc, char **argv)
 	    } else i++;
          }
       }
-      decode_sel_entry(buf,msg,sizeof(msg));
+      decode_sel_entry(buf,(char *)msg,sizeof(msg));
       printf("%s", evt_hdr); /*"RecId Date/Time_______*/
       printf("%s", msg);
    } else if (fnewevt) {
@@ -2598,7 +2622,7 @@ int i_events(int argc, char **argv)
       if (fdebug) printf("decoding standard IPMI event bytes\n");
       if (fdebug) dump_buf("IPMI event",buf,16,0);
       set_sel_opts(2,0, NULL,fdebug,futc);
-      rv = decode_sel_entry(buf,msg,sizeof(msg));
+      rv = decode_sel_entry(buf,(char *)msg,sizeof(msg));
       /* show header for the event record */
       printf("%s", evt_hdr); /*"RecId Date/Time_______*/
       printf("%s", msg);
