@@ -74,7 +74,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 extern int get_BiosVersion(char *str);
 extern int get_SystemGuid(uchar *guid);
 extern int GetSDR(int id, int *next, uchar *recdata, int srecdata, int *rlen);
-extern int get_device_guid(char *pbuf, int *sz); /*subs.c*/
+extern int get_device_guid(uchar *pbuf, int *sz); /*subs.c*/
 extern int oem_supermicro_get_health(char *pstr, int sz);  /*oem_supermicro.c*/
 extern int oem_supermicro_get_firmware_str(char *pstr, int sz); /*oem_supermicro.c*/
 
@@ -82,7 +82,7 @@ extern int oem_supermicro_get_firmware_str(char *pstr, int sz); /*oem_supermicro
  * Global variables 
  */
 static char * progname  = "ihealth";
-static char * progver   = "2.97";
+static char * progver   = "3.00";
 static char   fdebug    = 0;
 static char   fipmilan  = 0;
 static char   fcanonical = 0;
@@ -135,6 +135,36 @@ int oem_get_health(char *pstr, int sz)
    return rv;
 }
 
+char *getdmiprod(void)
+{
+   char *prod = "";
+#ifdef LINUX
+   static char dmiprod[32];
+   char cmd[160];
+   char *dmitmp = "/tmp/dmi.tmp";
+   FILE *fp;
+   int rv, i;
+   if (fipmilan) return(prod);
+   sprintf(cmd,"dmidecode | grep -A6 \"^Base Board\" |grep 'Product Name' |cut -f2 -d':' |awk '{ print $1 }' >%s",dmitmp);
+   rv = system(cmd); 
+   if (rv == 0) { 
+    fp = fopen(dmitmp,"r");
+    if (fp == NULL) rv = -1;
+    else {
+      if (fgets(dmiprod, sizeof(dmiprod), fp) == NULL) rv = -2;
+      else {
+          for (i=0; i<sizeof(dmiprod); i++) {
+             if (dmiprod[i] == '\n') { dmiprod[i] = '\0'; break; }
+          }
+          prod = dmiprod;
+      }
+      fclose(fp);
+    }
+   }
+#endif
+   return(prod);
+}
+
 int get_lan_stats(uchar chan)
 {
    uchar idata[2];
@@ -604,15 +634,19 @@ void show_devid_all(int dtype, uchar *devrec, int sdevrec)
 	     if (prod >= 0x200) prodstr = "(iRMC S2)"; 
 	     else prodstr = "";
              break;
-         case VENDOR_CISCO:      /*=0x00168b*/
+         case VENDOR_CISCO:      /*=0x00168b, 5771.*/
 	     if (prod == 0x0005) prodstr = "(UCS C200)"; 
 	     else prodstr = "";
              if (fipmilan) lan_ch_restrict = 1; /*fw bug, gets 0xC1 on ipmilan*/
              break;
+         case 0x003C0A:        /*=15370, Giga-Byte*/
+             prodstr = "";
+             lan_ch_restrict = 1; /*fw bug, gets 0xC1*/
+             break;
          case VENDOR_INTEL:     /*=0x000157*/
 	     if (do_hsc && (dtype == BMC)) /*if HSC option, also show extra*/
 	         sprintf(extraver," (Boot %x.%x PIA %x.%x)", /*BMC extra*/
-			devrec[11],devrec[12],devrec[13],devrec[14]);
+			  devrec[11],devrec[12],devrec[13],devrec[14]);
              switch(prod) {     /* show product names for some */
                  case 0x000C:   prodstr = "(TSRLT2)";    /*SCB2*/
                                 bChan = 7;  break;
@@ -645,15 +679,18 @@ void show_devid_all(int dtype, uchar *devrec, int sdevrec)
 				fmBMC = 1; break;
                  default:       prodstr = ""; break;
              }
-	     if (is_romley(mfg,prod)) {
-		intel_romley_desc(mfg,prod,&prodstr);
-		snprintf(prodoem,sizeof(prodoem),"(%s)",prodstr);
-		prodstr = prodoem;
-		do_me = 1; kcs_loops = URNLOOPS; 
-		do_hsc = 1; /*the HSC is embedded, so not the same*/
+             if (is_romley(mfg,prod)) {
+	        intel_romley_desc(mfg,prod,&prodstr);
+	        snprintf(prodoem,sizeof(prodoem),"(%s)",prodstr);
+	        prodstr = prodoem;
+	        do_me = 1; kcs_loops = URNLOOPS; 
+	        do_hsc = 1; /*the HSC is embedded, so not the same*/
 	        sprintf(extraver,".%d (Boot %x.%x)", /*BMC extra*/
 			(devrec[13] + (devrec[14] << 8)),devrec[11],devrec[12]);
-	     }
+             }
+             if (is_grantley(mfg,prod)) {
+	           intel_grantley_desc(mfg,prod,&prodstr);
+             }
              break;
          case VENDOR_KONTRON:     /*=0x003A98=15000.*/
 	     i = devrec[11] + (devrec[12] << 8);
@@ -753,6 +790,7 @@ void show_devid_all(int dtype, uchar *devrec, int sdevrec)
              prodstr = "";
              break;
 	} /*end switch(prod)*/
+	if (prodstr == "") prodstr = getdmiprod();
 	if (kcs_loops != 0) set_max_kcs_loops(kcs_loops); 
       } /*end-else BMC*/
 
@@ -796,7 +834,7 @@ int GetPowerOnHours(unsigned int *val)
 
 char *decode_selftest(int stat)
 {
-   uchar *s;
+   char *s;
    uchar b;
    if (stat == 0x0055) s = "(OK)";
    else {
