@@ -81,7 +81,7 @@
 
 /* Global data */
 static char * progname  = "ipicmg";
-static char * progver   = "2.97";
+static char * progver   = "3.00";
 static char   fdebug    = 0;
 static char   fset_mc   = 0;
 static uint8_t g_bus  = PUBLIC_BUS;
@@ -91,6 +91,96 @@ static uint8_t g_addrtype = ADDR_SMI;
 static uint8_t g_fruid = 0;
 static unsigned char PicmgExtMajorVersion;
 
+/* the LED color capabilities */
+static const char* led_color_str[] = { //__attribute__((unused)) = {
+   "reserved",
+   "BLUE",
+   "RED",
+   "GREEN",
+   "AMBER",
+   "ORANGE",
+   "WHITE",
+   "reserved"
+};
+
+
+static const char* amc_link_type_str[] = { // __attribute__((unused)) = {
+   "RESERVED",
+   "RESERVED1",
+   "PCI EXPRESS",
+   "ADVANCED SWITCHING1",
+   "ADVANCED SWITCHING2",
+   "ETHERNET",
+   "RAPIDIO",
+   "STORAGE",
+};
+
+static const char* amc_link_type_ext_str[][16]= { //  __attribute__((unused))
+	/* FRU_PICMGEXT_AMC_LINK_TYPE_RESERVED */
+	{
+		"", "", "", "", "", "", "", "",   "", "", "", "", "", "", "", ""
+	},
+	/* FRU_PICMGEXT_AMC_LINK_TYPE_RESERVED1 */
+	{
+		"", "", "", "", "", "", "", "",   "", "", "", "", "", "", "", ""
+	},
+	/* FRU_PICMGEXT_AMC_LINK_TYPE_PCI_EXPRESS */
+	{
+		"Gen 1 - NSSC",
+		"Gen 1 - SSC",
+		"Gen 2 - NSSC",
+		"Gen 2 - SSC",
+		"", "", "", "",
+		"", "", "", "", 
+		"", "", "", ""
+	},
+	/* FRU_PICMGEXT_AMC_LINK_TYPE_ADVANCED_SWITCHING1 */
+	{
+		"Gen 1 - NSSC",
+		"Gen 1 - SSC",
+		"Gen 2 - NSSC",
+		"Gen 2 - SSC",
+		"", "", "", "",
+		"", "", "", "", 
+		"", "", "", ""
+	},
+	/* FRU_PICMGEXT_AMC_LINK_TYPE_ADVANCED_SWITCHING2 */
+	{
+		"Gen 1 - NSSC",
+		"Gen 1 - SSC",
+		"Gen 2 - NSSC",
+		"Gen 2 - SSC",
+		"", "", "", "",
+		"", "", "", "", 
+		"", "", "", ""
+	},
+	/* FRU_PICMGEXT_AMC_LINK_TYPE_ETHERNET */
+	{
+   		"1000BASE-BX (SerDES Gigabit)",
+   		"10GBASE-BX410 Gigabit XAUI",
+   		"", "", 
+   		"", "", "", "",
+		"", "", "", "", 
+		"", "", "", ""
+	},
+	/* FRU_PICMGEXT_AMC_LINK_TYPE_RAPIDIO */
+	{
+   		"1.25 Gbaud transmission rate",
+   		"2.5 Gbaud transmission rate",
+   		"3.125 Gbaud transmission rate",
+   		"", "", "", "", "",
+		"", "", "", "", "", "", "", ""
+	},
+	/* FRU_PICMGEXT_AMC_LINK_TYPE_STORAGE */
+	{
+   		"Fibre Channel", 
+   		"Serial ATA", 
+   		"Serial Attached SCSI",
+   		"", "", "", "", "",
+		"", "", "", "", "", "", "", ""
+	}
+};
+
 typedef enum picmg_bused_resource_mode {
 	PICMG_BUSED_RESOURCE_SUMMARY,
 } t_picmg_bused_resource_mode ;
@@ -1297,7 +1387,7 @@ ipmi_picmg_clk_get(void * intf,  int clk_id,int clk_res,int mode)
 			val2str( rsp[3], picmg_clk_family_vals));
 		      printf("  - AccLVL: %3d [ %s ]\n", rsp[4],
 			oemval2str(rsp[3],rsp[4],picmg_clk_accuracy_vals));
-		      printf("  - Freq:   %d\n", freq);
+		      printf("  - Freq:   %lu\n", freq);
 		   }
 		}
 	}
@@ -1356,7 +1446,7 @@ printf("## index:   %d\n", msg_data[2]);
 printf("## setting: 0x%02x\n", msg_data[3]);
 printf("## family:  %d\n", msg_data[4]);
 printf("## acc:     %d\n", msg_data[5]);
-printf("## freq:    %d\n", freq );
+printf("## freq:    %lu\n", freq );
 printf("## res:     %d\n", msg_data[10]);
 #endif
 
