@@ -409,6 +409,7 @@ char *decode_rv(int rv)
 		/* ipmidir.h: ERGETTINGIPMIMESSAGE -504 */
        case ERR_BAD_FORMAT:   msg = "bad format"; break;
        case ERR_BAD_LENGTH:   msg = "length less than min"; break;
+       case ERR_SDR_MALFORMED: msg = "an SDR is malformed"; break;
        default:           
            sprintf(msgbuf,"error %d",rv);
            msg = msgbuf;
@@ -661,8 +662,9 @@ int ipmi_open(char fdebugcmd)
          /* Use IPMI LAN 2.0 if BMC said it only supports LAN2 */
 	 /* This is a violation of IPMI 2.0 Spec section 13.4,
 	  * but some HP firmware behaves this way, so handle it. */
-         rc = ipmi_open_lan2(gnode,lanp.user,lanp.pswd,fdebugcmd); 
          fDriverTyp = DRV_LAN2;
+         rc = ipmi_open_lan2(gnode,lanp.user,lanp.pswd,fdebugcmd); 
+         if (rc != 0) fDriverTyp = DRV_UNKNOWN;
       }
    } else {  /* local, not lan */
 #ifdef WIN32
@@ -1058,6 +1060,14 @@ int ipmi_getdeviceid(uchar *presp, int sresp, char fdebug)
    i = sresp;
    if (i > sizeof(my_devid)) i = sizeof(my_devid);
    memcpy(my_devid,presp,i); /* save device id for later use */
+   if (fdebug) {
+	  uchar maj,min,iver;
+      int vend, prod;
+	  get_devid_ver(&maj,&min,&iver);
+      get_mfgid(&vend, &prod);
+      printf("devid: firmware ver %x.%02x, IPMI v%02x, vendor=%d prod=%d\n",
+			 maj,min,iver,vend,prod);
+   }
    return(ACCESS_OK);   /* success */
 }
 
@@ -1355,7 +1365,7 @@ void parse_lan_options(int c, char *popt, char fdebugcmd)
                 break;
           case 'F':      /* force driver type */
                 i = set_driver_type(popt);
-		if (i == 0) fset_dtype = 1;
+				if (i == 0) fset_dtype = 1;
                 break;
           case 'T':      /* auth type */
                 i = atoi(popt);
