@@ -245,6 +245,7 @@ struct oemvalstr {
 #define SEV_CRIT  3
 
 /* Errors returned by ipmiutil functions, lan, etc, see decode_rv() */
+#define ERR_SDR_MALFORMED  -25 /*SDR is malformed */
 #define ERR_BAD_LENGTH     -24 /*length < MIN */
 #define ERR_BAD_FORMAT     -23 /*bad format*/
 #define ERR_USAGE          -22 /*usage/help requested*/
@@ -324,6 +325,8 @@ struct oemvalstr {
 #define BCOLON  ':'   /*delimeter some output with colons*/
 #define BCOMMENT '#'  /*delimeter '#' used for comments */
 
+#define RT_OEMIU  0xDB   /*record type for OEM ipmiutil events*/
+
 #ifndef LOG_WARN
 #define LOG_EMERG       0     //  system is unusable
 #define LOG_ALERT       1     //  action must be taken immediately
@@ -542,7 +545,7 @@ int   str2uchar(char *str_in, uchar *uchr_out);
 uchar atob(char *str_in);    /* calls str2uchar*/
 void  atoip(uchar *array,char *instr);
 int   get_system_info(uchar parm, char *pbuf, int *szbuf); /*subs.c*/
-int   set_system_info(uchar parm, uchar *pbuf, int szbuf); /*subs.c*/
+int   set_system_info(uchar parm, char *pbuf, int szbuf); /*subs.c*/
 int   ipmi_reserved_user(int vend, int userid);  /*subs.c*/
 	
 /* from mem_if.c */
