@@ -112,7 +112,7 @@ struct timeval {
 #endif
 
 int ipmi_timeout_mv = 10;   /* 10 seconds, was 5 sec */
-#if defined(BSD) || defined(MACOS) || defined(HPUX)
+#if defined(BSD7)
 #pragma pack(1)
 #endif
 
@@ -153,8 +153,10 @@ struct ipmi_cmdspec
         unsigned char netfn;
         unsigned char cmd;
 };
-#if defined(BSD) || defined(MACOS) || defined(HPUX)
+#if defined(BSD7)
 #pragma pack()
+#endif
+#if defined(BSD) || defined(MACOS) || defined(HPUX)
 /* FreeBSD 7.x ipmi ioctls, use _IOW */
 #define IPMI_IOC_MAGIC             'i'
 #define IPMICTL_RECEIVE_MSG_TRUNC  _IOWR(IPMI_IOC_MAGIC, 11, struct ipmi_recv)
@@ -239,6 +241,23 @@ static void dbgmsg(char *pattn, ...)
     fflush( fpdbg );
 }
 
+int set_cloexec(fd,fdebugcmd)
+{
+    int flags;
+	flags = fcntl(ipmi_fd, F_GETFD);
+	if (flags == -1) {
+	   if (fdebugcmd) printf("fcntl(get) errno = %d\n",errno);
+       return -1;
+    }
+	flags |= FD_CLOEXEC;
+	if (fcntl(ipmi_fd, F_SETFD, flags) == -1)
+    {
+	   if (fdebugcmd) printf("fcntl(set) errno = %d\n",errno);
+       return -1;
+    }
+	return 0;
+}
+
 int ipmi_open_mv(char fdebugcmd)
 {
     char *pdev;
@@ -283,6 +302,7 @@ int ipmi_open_mv(char fdebugcmd)
 	}
     }
     
+	set_cloexec(ipmi_fd,fdebugcmd);
     if (fdebugcmd) {
 	dbgmsg("ipmi_open_mv: successfully opened %s, fd=%d\n",pdev,ipmi_fd);
     }
