@@ -57,7 +57,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ipmiutil.h"
 
 static char *progname  = "ipmiutil";
-static char *progver   = "2.97";
+static char *progver   = "3.00";
 // static char fdebug = 0;
 /*int ipmiutil(int argc, char **argv); */
 
@@ -122,6 +122,8 @@ int i_discover(int argc, char **argv)
 }
 #endif
 
+#ifndef _WINDLL
+/* omit main if compiled as a Windows DLL */
 #ifdef WIN32
 int __cdecl
 #else
@@ -225,5 +227,6 @@ do_exit:
    }
    return(ret);
 }
+#endif
 
 /*end ipmiutil.c*/
