@@ -108,7 +108,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 /*
  * Global variables 
  */
-static char * progver   = "2.97";
+static char * progver   = "3.00";
 static char * progname  = "ireset";
 static uchar  ipmi_maj;
 static uchar  ipmi_min;
@@ -242,10 +242,10 @@ int set_boot_init_string(char *istr)
 	  idata[2] = iana[0];
 	  idata[3] = iana[1];
 	  idata[4] = iana[2];
-	  strncpy(&idata[5],&istr[n],13);
+	  strncpy((char *)&idata[5],&istr[n],13);
 	  n += 13;
       } else {
-	  strncpy(&idata[2],&istr[n],16);
+	  strncpy((char *)&idata[2],&istr[n],16);
 	  n += 16;
       }
       rlen = MAX_BUFFER_SIZE;
