@@ -49,6 +49,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #endif
 #endif
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 #include <time.h>
 #include "ipmicmd.h"
@@ -66,7 +67,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 void set_loglevel(int level);  /*prototype */
 extern char fsm_debug;  /*mem_if.c*/
 
-static char * progver   = "2.97";
+static char * progver   = "3.00";
 static char * progname  = "ismcoem";
 static int verbose = 0;
 static char fdebug = 0;
@@ -400,24 +401,34 @@ int decode_sensor_supermicro(uchar *sdr,uchar *reading,char *pstring, int slen)
 	   //if (dbg) printf("supermicro %x sensor reading %x\n",stype,reading);
            rv = 0;
 	   switch(bval) {
-           case 0x0000: pstr = "00 Low";    break;
-           case 0x0001: pstr = "01 Medium"; break;
-           case 0x0002: pstr = "02 High";   break;
-           case 0x0004: pstr = "04 Overheat";   break;
-           case 0x0007: pstr = "07 Not Installed";   break;
+           case 0x0000: pstr = "00_Low";    break;
+           case 0x0001: pstr = "01_Medium"; break;
+           case 0x0002: pstr = "02_High";   break;
+           case 0x0004: pstr = "04_Overheat";   break;
+           case 0x0007: pstr = "07_Not Installed";   break;
 	   default:  rv = -1;  break;
 	   }
            break;
         case 0x08:  /* Power Supply Status (Full/Discrete) Table 42-3 */
-	   rv = 0;
-	   switch(bval) {
-           case 0x00: pstr = "00 Absent"; break;     /*bit 0*/
-           case 0x01: pstr = "01 Present"; break;    /*bit 0*/
-           case 0x02: pstr = "02 Failure"; break;    /*bit 1*/
-           case 0x04: pstr = "04 Predict Fail"; break;  /*bit 2*/
-           case 0x08: pstr = "08 Input Lost"; break;    /*bit 3*/
-	   default:  rv = -1;  break;
-	   }
+          rv = 0;
+          switch(bval) {
+           case 0x00: pstr = "00_Absent"; break;     /*bit 0*/
+           case 0x01: pstr = "01_Present"; break;    /*bit 0*/
+           case 0x02: pstr = "02_Failure"; break;    /*bit 1*/
+           case 0x04: pstr = "04_Predict Fail"; break;  /*bit 2*/
+           case 0x08: pstr = "08_Input Lost"; break;    /*bit 3*/
+           default:  rv = -1;  break;
+          }
+           break;
+        case 0x0D:  /* HDD Status (Full/Discrete) Table 42-3 */
+          rv = 0;
+          switch(bval) {
+             case 0x00: pstr = "00_Absent"; break;     /*bit 0*/
+             case 0x01: pstr = "01_Present"; break;    /*bit 0*/
+             case 0x02: pstr = "02_Failure"; break;    /*bit 1*/
+             case 0x04: pstr = "04_Predict Fail"; break;  /*bit 2*/
+             default:  rv = -1;  break;
+          }
            break;
         default:
            break;
@@ -426,34 +437,70 @@ int decode_sensor_supermicro(uchar *sdr,uchar *reading,char *pstring, int slen)
    return(rv);
 }
 
+#define NPAIRS  26
+char rgpair[NPAIRS] = "ABCDEFGHIJKLMNOPQRSTUVWXYZ";
 int decode_mem_supermicro(int prod, uchar b2, uchar b3, char *desc, int *psz)
 {
-   int array, dimm, n;
+   int cpu, pair, dimm, n;
    int rv = -1;
+   int ver = 0;
    uchar bdata;
    if ((desc == NULL) || (psz == NULL)) return -1;
-   if (b2 == 0xff) bdata = b3;  /*ff is reserved*/
-   else  bdata = b2; /* normal case */
-   array = (bdata & 0xc0) >> 6;
+   if (b2 == 0xff) { ver = 1; bdata = b3; }  /*ff is reserved*/
+   else { ver = 2; bdata = b2; } /* normal case */
+#ifdef SMC_OLD
+   /* normal method for other vendors */
+   cpu = (bdata & 0xc0) >> 6;
    dimm = bdata & 0x3f;
+   /* SuperMicro advertised method (wrong) */
    /* bdata = 0x10 (16.) means CPU 1, DIMM 6 */
-   array = bdata / 10;
+   cpu = bdata / 10;
    dimm  = bdata % 10;
-
+#endif
 #ifdef DMIOK
-   /* Use DMI if we get confirmation about array/dimm indices. */
+   /* Use DMI if we get confirmation about cpu/dimm indices. */
    if (! is_remote()) {
       fsm_debug = fdebug;
-      rv = get_MemDesc(array,dimm,desc,psz);
+      rv = get_MemDesc(cpu,dimm,desc,psz);
       /* if (rv != 0) desc has "DIMM[%d}" */ 
    } 
 #endif
-
-   if (rv != 0) {
-      n = sprintf(desc,"DIMM%d/CPU%d",dimm,array);
-      *psz = n;
-      rv = 0;
+   /* ver 0 previous SuperMicro firmware returned all zeros here.
+    * ver 1 returns data3 with some info (X9)
+    * ver 2 returns data2 with some info (X9,X10)
+    * There have been bugs in these SuperMicro events, but this 
+    * has been derived from test data by comparing BIOS data. */
+   if (ver == 0) {
+      cpu = (bdata & 0xc0) >> 6;
+      dimm =bdata & 0x3f;
+	  pair = 0;
+      n = sprintf(desc,"CPU%d/DIMM%d",cpu,dimm);
+   } else if (ver == 1) {
+	  cpu = 1;
+      if (bdata > 0x80) cpu = 2;
+      pair = (bdata & 0x70) >> 4;
+      if (pair > NPAIRS) pair = NPAIRS - 1;
+	  dimm = (bdata & 0x07) + 1;  /*convert to 1-based*/
+      n = sprintf(desc,"P%d_DIMM%c%d",cpu,rgpair[pair],dimm);
+   } else {
+      /* ver 2 method: 2A 80 = P1_DIMMB1 */
+	  /* SuperMicro says:
+	   *  pair: %c (data2 >> 4) + 0x40 + (data3 & 0x3) * 3, (='B')
+	   *  dimm: %c (data2 & 0xf) + 0x27,    
+	   *  cpu:  %x (data3 & 0x03) + 1);
+	   */
+      cpu = (b3 & 0x0F) + 1; /*0x80=CPU1, 0x81=CPU2*/
+      pair = ((bdata & 0xF0) >> 4) - 1; /*0x10=pairA, 0x20=pairB*/
+      if (pair < 0) pair = 0;
+      if (pair > NPAIRS) pair = NPAIRS - 1;
+      dimm = (bdata & 0x0F) - 9; /*0x0A=dimmX1, 0x0B=dimmX2*/
+      n = sprintf(desc,"P%d_DIMM%c%d",cpu,rgpair[pair],dimm);
    }
+   if (fdebug) 
+	 printf("decode_mem_supermicro: v%d bdata=%02x(%d) cpu=%d dimm=%d pair=%d\n",ver,bdata,bdata,cpu,dimm,pair);
+
+   *psz = n;
+   rv = 0;
    return(rv);
 } /*end decode_mem_supermicro*/
 
@@ -481,6 +528,7 @@ int decode_sel_supermicro(uchar *evt, char *outbuf, int outsz, char fdesc,
    int sevid;
    ushort genid;
    uchar snum;
+   uchar data1, data2, data3;
          
    fdebug = fdbg;
    sevid = SEV_INFO;
@@ -489,13 +537,16 @@ int decode_sel_supermicro(uchar *evt, char *outbuf, int outsz, char fdesc,
    snum = evt[11];
    timestamp = evt[3] + (evt[4] << 8) + (evt[5] << 16) + (evt[6] << 24);
    genid = evt[7] | (evt[8] << 8);
+   data1 = evt[13];
+   data2 = evt[14];
+   data3 = evt[15];
    if (rectype == 0x02) 
    {
      sprintf(mybuf,"%02x [%02x %02x %02x]", evt[12],evt[13],evt[14],evt[15]);
      switch(evt[10]) {  /*sensor type*/
-        case 0xC0:      /* CPU Temp Sensor */
+     case 0xC0:      /* CPU Temp Sensor */
 	   type_str = "OEM_CpuTemp";
-	   switch((evt[13] &0x0f)) {  /*offset/data1 l.o. nibble*/
+	   switch((evt[13] & 0x0f)) {  /*offset/data1 l.o. nibble*/
            case 0x02:   /* CPU Temp Sensor Overheat event offset */
 		if (evt[12] & 0x80) {  /*EvTyp==0xF0 if deassert*/
 		   pstr = "CpuTemp Overheat OK"; sevid = SEV_INFO; 
@@ -504,10 +555,10 @@ int decode_sel_supermicro(uchar *evt, char *outbuf, int outsz, char fdesc,
 		}
 		rv = 0;
 		break;
-	   default: pstr = "CpuTemp Event"; break;
+	   default: pstr = "CpuTemp Event"; rv = 0; break;
 	   }
 	   break;
-        case 0xC2:      /* CPLD Event */
+     case 0xC2:      /* CPLD Event */
 	   type_str = "OEM_CPLD";
 	   switch((evt[13] & 0x0f)) {  /* data1 usu 0xa0*/
 	   case 0x00:
@@ -516,10 +567,35 @@ int decode_sel_supermicro(uchar *evt, char *outbuf, int outsz, char fdesc,
 		else { pstr = "CPLD Event Asserted";  sevid = SEV_MIN;  }
 		rv = 0;
 		break;
-	   default: pstr = "CPLD Event"; break;
+	   default: pstr = "CPLD Event"; rv = 0; break;
 	   }
 	   break;
-	default: /*other sensor types*/
+     case 0xD0:      /* BMC Event */
+	   type_str = "OEM_BMC";
+	   pstr = "BMC unknown event";
+	   sevid = SEV_CRIT; 
+	   if (data1 == 0x80 && data3 == 0xFF) {
+			switch(data2) {
+			  case 0x00: pstr = "BMC unexpected reset"; break;
+			  case 0x01: pstr = "BMC cold reset"; break;
+			  case 0x02: pstr = "BMC warm reset"; break;
+			}
+	   }
+	   rv = 0;
+	   break;
+     case 0xC5:      /* Observed Event: Storage, drive slot */
+	   /* usually OEM(c5) #52 - 6f [01 00 00]  */
+	   pstr = "OEMC5: Storage/DriveSlot fault";
+	   sevid = SEV_MAJ; 
+	   rv = 0;
+	   break;
+     case 0xC8:      /* Observed Event: Temp/Cooling issue, reboots */
+	   /* usually OEM(c8) #ff - 6f [a0 ff ff] */
+	   pstr = "OEMC8: Temp/Cooling fault";
+	   sevid = SEV_MAJ; 
+	   rv = 0;
+	   break;
+     default: /*other sensor types*/
 	   break;
      }
    }
@@ -530,12 +606,60 @@ int decode_sel_supermicro(uchar *evt, char *outbuf, int outsz, char fdesc,
    return(rv);
 }
 
+static int factory_defaults(int mode)
+{
+   int rv = -1;
+   int rlen;
+   uchar rdata[32];
+   uchar idata[16];
+   uchar cc;
+  /* 
+   From SMC IPMICFG -fde session:
+   start_kcs_transaction - 18 01    (get_device_id)
+   start_kcs_transaction - 18 25    (watchdog get)
+   start_kcs_transaction - b0 00 00 (unknown, invalid)
+   start_kcs_transaction - 18 01    (get_device_id)
+   start_kcs_transaction - 18 37    (get_system_guid)
+   start_kcs_transaction - 18 01    (get_device_id)
+   start_kcs_transaction - c0 41    (reset_factory_defaults, -fde)
+  */
+
+   /* b0 00 00: cmd=00 netfn=2C */
+   rlen = sizeof(rdata);
+   idata[0] = 0x00;  
+   rv = ipmi_cmdraw(0x00, (0xb0 >> 2), BMC_SA, PUBLIC_BUS, BMC_LUN,
+		    idata, 1, rdata, &rlen, &cc, fdebug);
+   if ((rv == 0) && (cc != 0)) rv = cc;
+   if (fdebug) printf("b0 00 returned %d\n",rv);
+   /* if (rv != 0) return(rv); */
+
+   if (mode == 2) {
+     rlen = sizeof(rdata);
+     rv = ipmi_cmdraw(0x37, (0x18 >> 2), BMC_SA, PUBLIC_BUS, BMC_LUN,
+			    idata, 0, rdata, &rlen, &cc, fdebug);
+     if ((rv == 0) && (cc != 0)) rv = cc;
+     if (fdebug) printf("get_guid returned %d\n",rv);
+     if (rv != 0) return(rv);
+   }
+
+   /* reset factory defaults cmd=0x41 netfn=0x30 (netfn/lun=0xC0) */
+   rlen = sizeof(rdata);
+   rv = ipmi_cmdraw(0x41, (0xc0 >> 2), BMC_SA, PUBLIC_BUS, BMC_LUN,
+		    idata, 0, rdata, &rlen, &cc, fdebug);
+   if ((rv == 0) && (cc != 0)) rv = cc;
+   if (fdebug) printf("factory default reset returned %d\n",rv);
+   if (rv != 0) return(rv);
+
+   return(rv);
+}
+
 static void usage(void)
 {
    printf("Usage: %s <command> [arg]\n",progname);
    printf("   intrusion                   = reset chassis intrusion\n");
    printf("   bmcstatus [enable| disable] = get/set BMC status\n");
    printf("   firmware                    = get extra firmware info\n");
+   printf("   factory                     = reset to factory defaults\n");
    printf("   lanport  [dedicated| lan1| failover] = get/set IPMI LAN port\n");
    printf("   powersupply <num>           = get PMBus PowerSupply status\n");
    printf("These commands may not work on all SuperMicro systems\n");
@@ -574,7 +698,11 @@ static int ipmi_smcoem_main(int  argc, char **argv)
       printf("Getting SMC Firmare Information ...\n");
       rv = oem_supermicro_get_firmware_str(msg, sizeof(msg));
       if (rv == 0) printf("%s\n",msg);
-   } else if (strncmp(argv[0],"lanport",9) == 0) {
+   } else if (strncmp(argv[0],"factory",7) == 0) {
+      rv = factory_defaults(0);
+      if (rv == 0) printf("Reset firmware to factory defaults\n");
+      else printf("Error %d resetting firmware to factory defaults\n",rv);
+   } else if (strncmp(argv[0],"lanport",7) == 0) {
       rv = oem_supermicro_get_lan_port(&val);
       if (rv == 0) {
         oem_supermicro_show_lan_port(val);
