@@ -403,7 +403,7 @@ int get_errno(void)
  /* For a list of all IANA enterprise mfg vendor numbers, 
   * see http://www.iana.org/assignments/enterprise-numbers 
   * Product numbers are different for each mfg vendor.  */
-#define N_MFG  43
+#define N_MFG  44
 static struct { int val; char *pstr; } mfgs[N_MFG] = {
     {0,   " "},
     {0x0000BA, "Toshiba"},
@@ -424,6 +424,7 @@ static struct { int val; char *pstr; } mfgs[N_MFG] = {
     {    7154, "IPMI forum"},
     {   11129, "Google"},
     {   12634, "PICMG"},
+	{   15370, "Giga-Byte"},  /*0x3C0A*/
     {   16394, "Pigeon Point"},
     {   20569, "Inventec ESC"},
     {   24673, "ServerEngines"},
@@ -608,7 +609,7 @@ static int sysinfo_has_len(uchar enc, int vendor)
    return(rv);
 }
 
-int get_device_guid(char *pbuf, int *szbuf)
+int get_device_guid(uchar *pbuf, int *szbuf)
 {
    int rv = -1;
    //uchar idata[8];
@@ -668,7 +669,7 @@ int get_sysinfo(uchar parm, uchar set, uchar block, uchar *pbuf, int *szbuf)
    return(rv);
 }
 
-int set_system_info(uchar parm, uchar *pbuf, int szbuf)
+int set_system_info(uchar parm, char *pbuf, int szbuf)
 {
    uchar idata[32];
    uchar rdata[8];
